summaryrefslogtreecommitdiffstats
path: root/c++/test/trefer.cpp
diff options
context:
space:
mode:
authorBinh-Minh Ribler <bmribler@hdfgroup.org>2018-07-21 05:40:57 (GMT)
committerBinh-Minh Ribler <bmribler@hdfgroup.org>2018-07-21 05:40:57 (GMT)
commit4f37cdcd36adb1bafcdf9af49b611180a64d157b (patch)
tree9111eecc09e15c8b70dd830ce23797d0e5bf0abf /c++/test/trefer.cpp
parentdd0a040ec807912b80a9f1779fbf46c65d01cd57 (diff)
downloadhdf5-4f37cdcd36adb1bafcdf9af49b611180a64d157b.zip
hdf5-4f37cdcd36adb1bafcdf9af49b611180a64d157b.tar.gz
hdf5-4f37cdcd36adb1bafcdf9af49b611180a64d157b.tar.bz2
Code improvement
Description: Moved the new H5Object::getInfo member functions to H5Location and made them overloaded with the existing H5Location::getObjinfo. This way is cleaner than the previous approach. Platforms tested: Linux/64 (jelly) Linux/32 (jam) Darwin (osx1010test)
Diffstat (limited to 'c++/test/trefer.cpp')
-rw-r--r--c++/test/trefer.cpp10
1 files changed, 5 insertions, 5 deletions
diff --git a/c++/test/trefer.cpp b/c++/test/trefer.cpp
index fa214df..562b127 100644
--- a/c++/test/trefer.cpp
+++ b/c++/test/trefer.cpp
@@ -481,19 +481,19 @@ static void test_reference_group()
fname = group.getFileName();
verify_val(fname, FILE1, "H5Group::getFileName",__LINE__,__FILE__);
// Check object type using Group::getInfo()
H5O_info_t oinfo;
HDmemset(&oinfo, 0, sizeof(oinfo));
- group.getInfo(".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)0, oinfo);
- verify_val(oinfo.type, H5O_TYPE_DATASET, "Group::getInfo",__LINE__,__FILE__);
+ group.getObjinfo(".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)0, oinfo);
+ verify_val(oinfo.type, H5O_TYPE_DATASET, "Group::getObjinfo",__LINE__,__FILE__);
// Check for out of bound query by index
try {
HDmemset(&oinfo, 0, sizeof(oinfo));
- group.getInfo(".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)9, oinfo);
+ group.getObjinfo(".", H5_INDEX_NAME, H5_ITER_INC, (hsize_t)9, oinfo);
// Should FAIL but didn't, so throw an invalid action exception
- throw InvalidActionException("Group::getInfo", "Out of bound index.");
+ throw InvalidActionException("Group::getObjinfo", "Out of bound index.");
} catch (Exception& err) {} // do nothing, failure expected
// Unlink one of the objects in the dereferenced group, and re-check
@@ -481,19 +481,19 @@ static void test_reference_group()
fname = group.getFileName();
verify_val(fname, FILE1, "H5Group::getFileName",__LINE__,__FILE__);
- // Check object type using Group::getInfo()
+ // Check object type using Group::getObjinfo()
H5O_info_t oinfo;
HDmemset(&oinfo, 0, sizeof(oinfo));